pub enum RelayChainMode {
Embedded,
ExternalRpc(Vec<Url>),
}Expand description
Possible modes for the relay chain to operate in.
Variants
Embedded
Spawn embedded relay chain node
ExternalRpc(Vec<Url>)
Connect to remote relay chain node via websocket RPC